Learn R Programming

flexsurv (version 0.1.5)

lines.flexsurvreg: Add fitted flexible survival curves to a plot

Description

Add fitted survival curves from a flexsurvreg model fit to an existing plot.

Equivalent to plot.flexsurvreg(...,add=TRUE).

Usage

## S3 method for class 'flexsurvreg':
lines(x, X=NULL, 
        col.fit="red", lty.fit=1, lwd.fit=2,...)

Arguments

x
Output from flexsurvreg, representing a fitted survival model object.
X
Matrix of covariate values to produce fitted survival curves for, as described in plot.flexsurvreg.
col.fit
Colour of the fitted survival curve(s).
lty.fit
Line type of the fitted survival curve(s).
lwd.fit
Line width of the fitted survival curve(s).
...
Other arguments to be passed to the generic plot and lines functions.

concept

Survival

See Also

flexsurvreg